@@ -42,7 +42,7 @@ def _interpret_args(args, kwargs):
 def _describe_args(args, kwargs):
     return ' '.join(_interpret_args(args,kwargs))
 
-def run(args, stdin=None, stdout=PIPE, stderr=None, cwd=None, **kwargs):
+def run(args, stdin=None, stdout=PIPE, stderr=None, cwd=None, no_display=False, **kwargs):
     """ Start a process using subprocess.Popen    
         
         Set close_fds=True so process doesn't inherit any other pipes we might be using.
@@ -55,7 +55,15 @@ def run(args, stdin=None, stdout=PIPE, stderr=None, cwd=None, **kwargs):
         
         stderr may also be nesoni.io.STDOUT
     """
-    args = _interpret_args(args, kwargs)    
+    args = _interpret_args(args, kwargs)
+    
+    if not no_display:
+        env = None
+    else:
+        env = dict(os.environ)
+        if 'DISPLAY' in env:
+            del env['DISPLAY']
+    
     return subprocess.Popen(
         args,
         bufsize=1<<24,
@@ -63,8 +71,9 @@ def run(args, stdin=None, stdout=PIPE, stderr=None, cwd=None, **kwargs):
         stdout=stdout,
         stderr=stderr,
         cwd=cwd,
+        env=env,
         close_fds=True,
-    )
+        )
     
 
 @contextlib.contextmanager
@@ -303,7 +312,10 @@ class Pipe_writer(object):
 
 
 def open_gzip_writer(filename):
-    return Pipe_writer(filename, ['gzip'])
+    try:
+        return Pipe_writer(filename, ['pigz'])
+    except OSError:
+        return Pipe_writer(filename, ['gzip'])
 
 def open_bzip2_writer(filename):    
     return Pipe_writer(filename, ['bzip2'])
@@ -891,7 +903,7 @@ class Grouped_table(collections.OrderedDict):
                 )
 
 
-def read_grouped_table(filename, group_cast=[('All',str)], default_group='All'):
+def read_grouped_table(filename, group_cast=[], default_group='All'):
     """ 
     Read some groups of columns from a grouped-column table file.
     
@@ -909,8 +921,11 @@ def read_grouped_table(filename, group_cast=[('All',str)], default_group='All'):
     group_cast = collections.OrderedDict(group_cast)
 
     reader = Table_reader(filename, default_group)
+    
+    for group in reader.groups:
+        if group not in group_cast:
+            group_cast[group] = str
 
-    group_types = { }
     groups = { }
     group_columns = { }
     group_column_names = { }
@@ -932,7 +947,7 @@ def read_grouped_table(filename, group_cast=[('All',str)], default_group='All'):
 
     result = Grouped_table(reader.headings[0])
     result.comments = reader.comments
-    for group in groups:
+    for group in group_cast:
         result[group] = named_matrix_type(names,group_column_names[group])(groups[group])
     return result
 
